#!/usr/bin/env bash
set -x #echo on

RPM_DESCRIPTION="Redpoint Positioning RTLS Addon Raymond Vehicle Attribute"
RPM_MAINTAINER=help@redpointpositioning.com
RPP_VENDOR="Redpoint Positioning, Inc."
PROJECT_HOME=${WORKSPACE}

PROJECT='rtls-addon-raymond-vehicle-attribute'
ADDON_NAME_FOLDER='raymond_vehicle_attribute'

export PATH=/usr/local/bin:/usr/local/rbenv/shims:$PATH

VERSION="$( server/addons/${ADDON_NAME_FOLDER}/sys-services/rtls-get-version.sh )"
RELEASE="$( server/addons/${ADDON_NAME_FOLDER}/sys-services/rtls-get-release.sh )"
FILE="$( server/addons/${ADDON_NAME_FOLDER}/sys-services/rtls-get-file-name.sh )"

echo "PROJECT_HOME:       ${PROJECT_HOME}"
echo "BUILDING ON BRANCH: ${BRANCH_NAME}"
echo "VERSION:            ${VERSION}"
echo "RELEASE:            ${RELEASE}"
echo "FILE:               ${FILE}"

rm -f "${PROJECT_HOME}"/*.deb
rm -f "${PROJECT_HOME}"/*.rpm
[ -d "${PROJECT_HOME}"/releases ] && rm -f "${PROJECT_HOME}"/releases/*

fpm -s dir -t deb -f \
  --description "${RPM_DESCRIPTION}" \
  --maintainer "${RPM_MAINTAINER}" \
  --vendor "${RPP_VENDOR}" \
  --license "Proprietary" \
  --provides "${PROJECT}" \
  --exclude ".git" \
  --rpm-use-file-permissions \
  --before-remove server/addons/${ADDON_NAME_FOLDER}/sys-services/pre-uninstall.sh \
  --before-install server/addons/${ADDON_NAME_FOLDER}/sys-services/pre-install.sh \
  --after-install server/addons/${ADDON_NAME_FOLDER}/sys-services/post-install.sh \
  --before-upgrade server/addons/${ADDON_NAME_FOLDER}/sys-services/pre-update.sh \
  --after-upgrade server/addons/${ADDON_NAME_FOLDER}/sys-services/post-update.sh \
  --after-remove server/addons/${ADDON_NAME_FOLDER}/sys-services/after-remove.sh \
  --depends "nodejs (>= 20.5.1)" \
  --depends 'rtls-server >= 2024.1.735' \
  --depends 'jq' \
  --deb-group rtls \
  --deb-user rtls \
  --name "${PROJECT}" \
  --version "${VERSION}" \
  --iteration "${RELEASE}" \
  --package "${PROJECT_HOME}" \
  ./server/addons/${ADDON_NAME_FOLDER}.js=/usr/rtls/rtls-frontend/server/addons/${ADDON_NAME_FOLDER}.js \
  ./server/addons/${ADDON_NAME_FOLDER}/=/usr/rtls/rtls-frontend/server/addons/${ADDON_NAME_FOLDER} \
